pub struct DetectorConfig {
pub method: AnomalyMethod,
pub threshold: f64,
pub min_samples: usize,
pub max_reference: usize,
}Expand description
Configuration for VectorAnomalyDetector.
Fields
method: AnomalyMethodDetection method.
threshold: f64Anomaly threshold.
Defaults: 3.0 for AnomalyMethod::ZScore /
AnomalyMethod::MahalanobisApprox, 0.7 for
AnomalyMethod::IsolationScore.
min_samples: usizeMinimum number of reference vectors required before detection starts.
max_reference: usizeMaximum number of reference vectors to retain (drop oldest on overflow).
Implementations
Sourceimpl DetectorConfig
impl DetectorConfig
Sourcepub fn with_method(method: AnomalyMethod) -> Self
pub fn with_method(method: AnomalyMethod) -> Self
Create a config with sensible defaults for the given method.