pub struct SemanticAnomalyDetector { /* private fields */ }Expand description
Detects anomalous embeddings using distance-from-centroid analysis.
Supports three detection methods:
- ZScore: z-score of distances to centroid
- IQR: interquartile range on distances
- DistanceBased: mean + multiplier * std_dev threshold on distances
Example
use ipfrs_semantic::anomaly_detector::{
SemanticAnomalyDetector, AnomalyConfig, SemanticAnomalyMethod,
};
let config = AnomalyConfig::default();
let mut detector = SemanticAnomalyDetector::new(config);
// Add some normal embeddings
for i in 0..20 {
detector.add_embedding(&format!("doc_{i}"), vec![0.1 * i as f64, 0.0, 0.0]);
}
// Detect anomalies
let results = detector.detect_all();Implementations
Sourceimpl SemanticAnomalyDetector
impl SemanticAnomalyDetector
Sourcepub fn new(config: AnomalyConfig) -> Self
pub fn new(config: AnomalyConfig) -> Self
Create a new detector with the given configuration.
Sourcepub fn add_embedding(&mut self, doc_id: &str, embedding: Vec<f64>)
pub fn add_embedding(&mut self, doc_id: &str, embedding: Vec<f64>)
Add an embedding and incrementally recompute the centroid.
Sourcepub fn remove_embedding(&mut self, doc_id: &str) -> bool
pub fn remove_embedding(&mut self, doc_id: &str) -> bool
Remove an embedding by doc_id. Returns true if found and removed.
Recomputes the centroid from scratch after removal.
Sourcepub fn detect_all(&mut self) -> Vec<SemanticAnomalyResult>
pub fn detect_all(&mut self) -> Vec<SemanticAnomalyResult>
Run detection on all stored embeddings using the configured method.
Sourcepub fn detect_single(&self, embedding: &[f64]) -> SemanticAnomalyResult
pub fn detect_single(&self, embedding: &[f64]) -> SemanticAnomalyResult
Check if a single new embedding is anomalous against existing data.
Does not add the embedding to the detector.
Sourcepub fn compute_centroid(embeddings: &[(String, Vec<f64>)]) -> Vec<f64>
pub fn compute_centroid(embeddings: &[(String, Vec<f64>)]) -> Vec<f64>
Compute the centroid (mean vector) of the given embeddings.
Sourcepub fn euclidean_distance(a: &[f64], b: &[f64]) -> f64
pub fn euclidean_distance(a: &[f64], b: &[f64]) -> f64
Euclidean distance between two vectors.
Sourcepub fn distances_to_centroid(&self) -> Vec<(String, f64)>
pub fn distances_to_centroid(&self) -> Vec<(String, f64)>
Compute (doc_id, distance) pairs for all stored embeddings to centroid.
Sourcepub fn embedding_count(&self) -> usize
pub fn embedding_count(&self) -> usize
Number of stored embeddings.
Sourcepub fn stats(&self) -> AnomalyDetectorStats
pub fn stats(&self) -> AnomalyDetectorStats
Get detector statistics.