pub struct RouteScore {
pub node_id: String,
pub topic: String,
pub similarity: f32,
pub load_factor: f64,
}Expand description
A candidate routing result for a single (node, topic) pair.
Fields
node_id: StringNode identifier.
topic: StringTopic label matched.
similarity: f32Cosine similarity between the query and the topic embedding.
load_factor: f64Load factor at the time the score was computed: current_load / capacity.max(1).
Implementations
Sourceimpl RouteScore
impl RouteScore
Sourcepub fn combined_score(&self) -> f64
pub fn combined_score(&self) -> f64
Combined routing score that penalizes heavily loaded nodes.
combined_score = similarity * (1.0 - load_factor * 0.3)