pub struct EmbeddingPipelineConfig {
pub dimensions: usize,
pub normalization: NormalizationStrategy,
pub truncate_to_dims: bool,
pub pad_value: f32,
}Expand description
Configuration for an EmbeddingPipeline.
Fields
dimensions: usizeTarget dimensionality for all output vectors.
normalization: NormalizationStrategyWhich normalization strategy to apply.
truncate_to_dims: boolWhether to truncate or pad vectors to exactly dimensions.
pad_value: f32Scalar used to pad vectors that are shorter than dimensions.