Module entity_linker

Module entity_linker 

Semantic Entity Linker

Links named entity mentions in queries to their canonical entities in a knowledge base, using embedding similarity and surface form matching.

Structs

KbEntity
A canonical entity stored in the knowledge base.
LinkedMention
A resolved link from a mention text to a knowledge-base entity.
LinkerConfig
Configuration for the SemanticEntityLinker.
LinkerStats
Aggregated statistics for a SemanticEntityLinker instance.
SemanticEntityLinker
A linker that resolves mention texts to canonical knowledge-base entities.

Enums

MentionKind
The kind of match that linked a mention to an entity.

Functions

cosine_sim
Compute the cosine similarity between two equal-length float vectors.