pub struct LinkedMention {
pub mention_text: String,
pub entity_id: u64,
pub kind: MentionKind,
pub confidence: f32,
}Expand description
A resolved link from a mention text to a knowledge-base entity.
Fields
mention_text: StringThe original mention text as it appeared in the query.
entity_id: u64The entity that this mention was resolved to.
kind: MentionKindThe kind of evidence used to resolve this mention.
confidence: f32Confidence score in [0.0, 1.0].