pub struct LinkerConfig {
pub exact_match_confidence: f32,
pub alias_match_confidence: f32,
pub embedding_threshold: f32,
pub embedding_match_confidence_scale: f32,
}Expand description
Configuration for the SemanticEntityLinker.
Fields
exact_match_confidence: f32Confidence assigned to an exact-name match.
alias_match_confidence: f32Confidence assigned when a mention matches a known alias.
embedding_threshold: f32Minimum cosine similarity required to accept an embedding match.
embedding_match_confidence_scale: f32confidence = cosine_similarity * embedding_match_confidence_scale.