pub struct CompactionPlan {
pub reason: CompactionReason,
pub estimated_vectors_after: usize,
pub estimated_bytes_saved: u64,
pub priority: CompactionPriority,
}Expand description
A concrete recommendation to compact an index, including estimated impact.
Fields
reason: CompactionReasonWhy the compaction was triggered.
estimated_vectors_after: usizeEstimated number of live vectors after the rebuild.
estimated_bytes_saved: u64Approximate bytes that will be freed by the compaction.
priority: CompactionPriorityHow urgently the compaction should be performed.