pub struct AlignmentMatrix {
pub src_lang: LangId,
pub tgt_lang: LangId,
pub matrix: Vec<f64>,
pub quality: f64,
}Expand description
Alignment transformation from one language space to another (row-major dim×dim).
Fields
src_lang: LangIdtgt_lang: LangIdmatrix: Vec<f64>Row-major dim×dim matrix
quality: f64Mean cosine similarity on the anchor pairs after alignment