pub struct ExpansionConfig {
pub max_expansions_per_term: usize,
pub min_weight: f64,
pub include_synonyms: bool,
pub include_hypernyms: bool,
pub include_hyponyms: bool,
pub include_related: bool,
pub boost_exact_match: f64,
}Expand description
Tuning knobs for QueryExpansionEngine.
Fields
max_expansions_per_term: usizeMaximum number of expansion terms added per original token.
min_weight: f64Minimum weight an expansion must have to be kept.
include_synonyms: boolWhether to add synonyms.
include_hypernyms: boolWhether to add hypernyms.
include_hyponyms: boolWhether to add hyponyms.
Whether to add context-map related terms.
boost_exact_match: f64Boost factor applied to the original query tokens (weight = this value).