pub enum Linkage {
Ward,
Complete,
Average,
Single,
}Expand description
Linkage criterion used by agglomerative clustering.
Variants
Ward
Minimise variance (simplified: behaves like Average in this implementation).
Complete
Distance between the two farthest members of each cluster.
Average
Mean of all pairwise distances between cluster members.
Single
Distance between the two nearest members of each cluster.