pub struct SentimentConfig {
pub window_size: usize,
pub negation_window: usize,
pub aspect_keywords: Vec<String>,
}Expand description
Configuration for SentimentAnalyzer.
Fields
window_size: usizeNumber of tokens either side of an aspect keyword to consider when computing aspect-level sentiment.
negation_window: usizeNumber of tokens before a sentiment word to look for negators.
aspect_keywords: Vec<String>Domain-specific aspect keywords to track.