pub struct ExtractionResult {
pub selected_indices: Vec<usize>,
pub sentences: Vec<ExtractorScoredSentence>,
pub coverage_score: f64,
}Expand description
Result of an extraction run.
Fields
selected_indices: Vec<usize>Indices of the selected sentences, in selection order.
sentences: Vec<ExtractorScoredSentence>All sentences with their final scores and selection flags.
coverage_score: f64Coverage: average of the maximum similarity from each unselected sentence to its nearest selected sentence.