pub struct SummarizerConfig {
pub method: SummarizationMethod,
pub min_sentence_length: usize,
pub max_sentence_length: usize,
pub stop_words: Vec<String>,
}Expand description
Configuration for TextSummarizer.
Fields
method: SummarizationMethodWhich algorithm to use.
min_sentence_length: usizeMinimum character length for a sentence to be considered (inclusive).
max_sentence_length: usizeMaximum character length for a sentence to be considered (inclusive).
stop_words: Vec<String>Words to ignore during tokenization.