pub struct SemanticTokenizer { /* private fields */ }Expand description
A configurable tokenizer for semantic search indexing.
Supports whitespace splitting, word-boundary splitting, and character n-gram generation. Tokens can be lowercased, length-filtered, and stop-word filtered.
Implementations
Sourceimpl SemanticTokenizer
impl SemanticTokenizer
Sourcepub fn new(config: TokenizerConfig) -> Self
pub fn new(config: TokenizerConfig) -> Self
Create a new tokenizer with the given configuration.
Sourcepub fn tokenize(&mut self, text: &str) -> Vec<Token>
pub fn tokenize(&mut self, text: &str) -> Vec<Token>
Tokenize text according to the current mode and filters.
Sourcepub fn token_count(&self, text: &str) -> usize
pub fn token_count(&self, text: &str) -> usize
Return the number of tokens that would be produced without allocating
full Token structs.
Sourcepub fn add_stop_word(&mut self, word: &str)
pub fn add_stop_word(&mut self, word: &str)
Add a stop word.
Sourcepub fn remove_stop_word(&mut self, word: &str) -> bool
pub fn remove_stop_word(&mut self, word: &str) -> bool
Remove a stop word. Returns true if it was present.
Sourcepub fn is_stop_word(&self, word: &str) -> bool
pub fn is_stop_word(&self, word: &str) -> bool
Check whether word is in the stop-word list.
Sourcepub fn normalize(&self, text: &str) -> String
pub fn normalize(&self, text: &str) -> String
Normalize text by applying lowercasing (if configured).
Sourcepub fn stats(&self) -> TokenizerStats
pub fn stats(&self) -> TokenizerStats
Return current tokenizer statistics.