pub struct Token {
pub text: String,
pub position: usize,
pub byte_offset: usize,
}Expand description
A single token produced by the tokenizer.
Fields
text: StringThe (possibly lowercased) token text.
position: usizeZero-based position among emitted tokens in the source text.
byte_offset: usizeByte offset where this token begins in the original text.