pub struct SemanticDiversifier {
pub config: DiversifierConfig,
/* private fields */
}Expand description
Diversifies a ranked list of candidates using Maximal Marginal Relevance.
Each call to select greedily picks items
that simultaneously maximise relevance to the query and minimise similarity
to previously selected items.
Fields
config: DiversifierConfigMMR configuration (lambda, etc.).
Implementations
Sourceimpl SemanticDiversifier
impl SemanticDiversifier
Sourcepub fn new(config: DiversifierConfig) -> Self
pub fn new(config: DiversifierConfig) -> Self
Create a new diversifier with the given configuration.
Sourcepub fn select(
&mut self,
_query: &[f32],
candidates: Vec<DiversificationCandidate>,
k: usize,
) -> Vec<DiversifiedResult>
pub fn select( &mut self, _query: &[f32], candidates: Vec<DiversificationCandidate>, k: usize, ) -> Vec<DiversifiedResult>
Select up to k diversified results from candidates using MMR.
The algorithm greedily builds a selected set S, starting from empty.
Each iteration scores every remaining candidate with:
mmr = lambda * relevance_score - (1 - lambda) * max_sim_to_selectedTies are broken by doc_id ascending.
Returns an empty Vec when candidates is empty or k == 0.
Sourcepub fn stats(&self) -> &DiversifierStats
pub fn stats(&self) -> &DiversifierStats
Return a reference to the accumulated statistics.
Sourcepub fn set_lambda(&mut self, lambda: f32)
pub fn set_lambda(&mut self, lambda: f32)
Override the lambda trade-off parameter, clamped to [0.0, 1.0].