pub struct EmbeddingCompressionCodec { /* private fields */ }Expand description
Codec for compressing dense embedding vectors.
Use register_codec to create named codec configurations,
then call compress / decompress as needed.
Implementations
Sourceimpl EmbeddingCompressionCodec
impl EmbeddingCompressionCodec
Sourcepub fn register_codec(
&mut self,
name: &str,
method: EccMethod,
bits: u8,
block_size: usize,
) -> EccCodecId
pub fn register_codec( &mut self, name: &str, method: EccMethod, bits: u8, block_size: usize, ) -> EccCodecId
Register a new codec and return its id.
bits must be 4, 8, or 16. block_size is used by PQ / HybridPQ.
Sourcepub fn register_from_config(&mut self, config: &EccCodecConfig) -> EccCodecId
pub fn register_from_config(&mut self, config: &EccCodecConfig) -> EccCodecId
Register a codec from a full EccCodecConfig.
Sourcepub fn get_spec(&self, id: EccCodecId) -> Option<&EccCodecSpec>
pub fn get_spec(&self, id: EccCodecId) -> Option<&EccCodecSpec>
Look up a codec spec by id.
Sourcepub fn codec_count(&self) -> usize
pub fn codec_count(&self) -> usize
Return the number of registered codecs.
Sourcepub fn compress(
&mut self,
codec_id: EccCodecId,
embedding: &[f64],
) -> Result<EccCompressed, EccError>
pub fn compress( &mut self, codec_id: EccCodecId, embedding: &[f64], ) -> Result<EccCompressed, EccError>
Compress a single embedding vector using the specified codec.
Sourcepub fn decompress(
&self,
compressed: &EccCompressed,
) -> Result<Vec<f64>, EccError>
pub fn decompress( &self, compressed: &EccCompressed, ) -> Result<Vec<f64>, EccError>
Decompress a previously compressed payload.
Sourcepub fn compress_batch(
&mut self,
codec_id: EccCodecId,
embeddings: &[Vec<f64>],
) -> Vec<Result<EccCompressed, EccError>>
pub fn compress_batch( &mut self, codec_id: EccCodecId, embeddings: &[Vec<f64>], ) -> Vec<Result<EccCompressed, EccError>>
Compress a batch of embeddings with the same codec.
Sourcepub fn decompress_batch(
&self,
batch: &[EccCompressed],
) -> Vec<Result<Vec<f64>, EccError>>
pub fn decompress_batch( &self, batch: &[EccCompressed], ) -> Vec<Result<Vec<f64>, EccError>>
Decompress a batch of compressed payloads.
Sourcepub fn reconstruction_error(original: &[f64], decompressed: &[f64]) -> f64
pub fn reconstruction_error(original: &[f64], decompressed: &[f64]) -> f64
Compute mean squared error between original and decompressed vectors.
Sourcepub fn estimate_ratio(&self, codec_id: EccCodecId, dim: usize) -> f64
pub fn estimate_ratio(&self, codec_id: EccCodecId, dim: usize) -> f64
Estimate the theoretical compression ratio for a given codec and vector dimension.
The estimate is based on the quantization bit-width and method overhead.
Sourcepub fn codec_stats(&self) -> EccCodecStats
pub fn codec_stats(&self) -> EccCodecStats
Compute aggregate statistics over the compression log.
Sourcepub fn log_entries(&self) -> &VecDeque<EccCompressionRecord>
pub fn log_entries(&self) -> &VecDeque<EccCompressionRecord>
Return a read-only view of the compression log.