Semantic Entity Linker
Links named entity mentions in queries to their canonical entities in a knowledge base, using embedding similarity and surface form matching.
Structs
- KbEntity
- A canonical entity stored in the knowledge base.
- Linked
Mention - A resolved link from a mention text to a knowledge-base entity.
- Linker
Config - Configuration for the
SemanticEntityLinker. - Linker
Stats - Aggregated statistics for a
SemanticEntityLinkerinstance. - Semantic
Entity Linker - A linker that resolves mention texts to canonical knowledge-base entities.
Enums
- Mention
Kind - The kind of match that linked a mention to an entity.
Functions
- cosine_
sim - Compute the cosine similarity between two equal-length float vectors.