pub struct SemanticClusterer {
pub algorithm: ClusterAlgorithm,
pub dims: usize,
}Expand description
Multi-algorithm semantic vector clustering engine.
use ipfrs_semantic::semantic_clusterer::{
SemanticClusterer, ClusterAlgorithm, ScClusterPoint,
};
let points: Vec<ScClusterPoint> = (0..20)
.map(|i| ScClusterPoint::new(format!("p{i}"), vec![(i % 4) as f64, (i / 4) as f64]))
.collect();
let clusterer = SemanticClusterer::new(
ClusterAlgorithm::KMeans { k: 4, max_iter: 100, tolerance: 1e-6 },
2,
);
let result = clusterer.fit(&points).expect("clustering failed");
assert_eq!(result.clusters.len(), 4);Fields
algorithm: ClusterAlgorithmAlgorithm configuration.
dims: usizeExpected embedding dimensionality.
Implementations
Sourceimpl SemanticClusterer
impl SemanticClusterer
Sourcepub fn new(algorithm: ClusterAlgorithm, dims: usize) -> Self
pub fn new(algorithm: ClusterAlgorithm, dims: usize) -> Self
Create a new clusterer with the given algorithm and embedding dimension.
Sourcepub fn fit(
&self,
points: &[ScClusterPoint],
) -> Result<ScClusteringResult, ClusterError>
pub fn fit( &self, points: &[ScClusterPoint], ) -> Result<ScClusteringResult, ClusterError>
Run clustering on the provided points.
Returns a ScClusteringResult on success.
Sourcepub fn predict(
&self,
point: &ScClusterPoint,
result: &ScClusteringResult,
) -> Option<usize>
pub fn predict( &self, point: &ScClusterPoint, result: &ScClusteringResult, ) -> Option<usize>
Assign a new point to the nearest cluster centroid in result.
Returns None when result has no clusters.
Sourcepub fn cosine_distance(a: &[f64], b: &[f64]) -> f64
pub fn cosine_distance(a: &[f64], b: &[f64]) -> f64
Cosine distance: 1 - cosine_similarity(a, b).
Returns 1.0 for zero vectors.
Sourcepub fn euclidean_distance(a: &[f64], b: &[f64]) -> f64
pub fn euclidean_distance(a: &[f64], b: &[f64]) -> f64
Euclidean distance between two vectors of equal length.
Sourcepub fn silhouette_score(
points: &[ScClusterPoint],
result: &ScClusteringResult,
) -> f64
pub fn silhouette_score( points: &[ScClusterPoint], result: &ScClusteringResult, ) -> f64
Mean silhouette coefficient for the clustering.
Uses a random subset of up to 100 points when the dataset is large.
Sourcepub fn compute_centroid(embeddings: &[&[f64]]) -> Vec<f64>
pub fn compute_centroid(embeddings: &[&[f64]]) -> Vec<f64>
Compute the centroid (element-wise mean) of a set of embeddings.
Returns a zero vector when embeddings is empty or their slices are empty.
Sourcepub fn stats(result: &ScClusteringResult) -> ScClustererStats
pub fn stats(result: &ScClusteringResult) -> ScClustererStats
Summary statistics for a completed clustering result.