Vector Index Optimizer
Selects and maintains optimal vector index structures based on workload analysis. Supports Flat, IVF-Flat, Product Quantization, HNSW-like, LSH, and Tree structures. Uses pure-Rust cost models to recommend and maintain the best index for a given workload.
Structs
- Index
Recommendation - Recommendation produced by the optimizer.
- Index
Stats - Snapshot of a live index’s runtime statistics.
- Optimizer
Config - Configuration for the
VectorIndexOptimizer. - Optimizer
Stats - Aggregate statistics for the optimizer itself.
- Vector
Index Optimizer - Production-quality vector index optimizer.
- Workload
Profile - Workload characteristics used to drive index selection.
Enums
- Index
Structure - Supported index structures for approximate nearest-neighbour search.
- Maintenance
Action - Maintenance operation to be applied to an index.
- Optimization
Criterion - Criterion used to compare and select index structures.
- Optimizer
Error - Errors produced by the optimizer.
Functions
- xorshift64
- Xorshift64 PRNG — advances
stateand returns the next pseudo-random u64. - xorshift_
f64 - Returns a pseudo-random f64 in
[0, 1)usingxorshift64.
Type Aliases
- VioIndex
Stats - Type alias for
IndexStats(re-exported asVioIndexStatsto avoid conflict withstats::IndexStatswhich is already exported at crate level). - VioOptimizer
Config - Type alias for
OptimizerConfig(re-exported asVioOptimizerConfigto avoid conflict withsemantic_query_optimizer::OptimizerConfigwhich is already exported at crate level). - VioOptimizer
Error - Type alias for
OptimizerError(re-exported asVioOptimizerErrorto avoid conflict withsemantic_query_optimizer::OptimizerErrorwhich is already exported at crate level). - VioOptimizer
Stats - Type alias for
OptimizerStats(re-exported asVioOptimizerStatsto avoid conflict withsemantic_query_optimizer::OptimizerStatswhich is already exported at crate level).